==> nextcloud-25.0.7.tgz: nextcloud/apps/notifications/l10n/ko.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "%s 님 안녕하세요",
    "Hello %s," : "안녕하세요 %s 님,",
    "Admin notifications" : "관리자 알림",
    "Notifications" : "알림",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "이 앱은 Nextcloud 알림 API의 백엔드 및 프론트엔드입니다.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "이 앱은 Nextcloud 알림 API의 백엔드 및 프론트엔드입니다.\n\t\tAPI를 사용하여 다른 앱에서 웹 UI에 알림을 표시하고 클라이언트에 메시지를 전달할 수 있습니다. 다음 기능을 사용할 수 있습니다:\n\n📬 연합 파일 공유: 새 원격 공유 수신\n\n📑 댓글: 다른 사용자가 여러분을 파일에서 언급함\n\n🚢 업데이트 알림: Nextcloud나 앱 업데이트 알림\n\n📣 공지 센터: 관리자가 공지를 올림",
    "Failed to perform action" : "동작을 수행할 수 없음",
    "Dismiss" : "해제",
    "seconds ago" : "초 전",
    "Failed to dismiss notification" : "알림을 해제할 수 없음",
    "in {path}" : "{path}에 있음",
    "Dismiss all notifications" : "모든 알림 해제",
    "No notifications" : "알림 없음",
    "Failed to dismiss all notifications" : "모든 알림을 해제할 수 없음",
    "Send email reminders about unhandled notifications after:" : "다음 기간동안 확인하지 않은 알림을 이메일로 보내기:",
    "Play sound when a new notification arrives" : "새로운 알림이 도착할 때 소리 재생하기",
    "Play sound when a call started (requires Nextcloud Talk)" : "새 통화가 시작될 때 소리 재생하기 (Nextcloud Talk가 필요합니다)",
    "Never" : "하지 않음",
    "1 hour" : "1시간",
    "3 hours" : "3시간",
    "1 day" : "1일",
    "1 week" : "1주",
    "Your settings have been updated." : "설정이 업데이트되었습니다.",
    "You need to set up your email address before you can receive notification emails." : "알림 이메일을 받으려면 이메일 주소를 설정해야 합니다."
},
"nplurals=1; plural=0;");

==> nextcloud-26.0.9.tgz: nextcloud/apps/notifications/l10n/ko.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "%s님 안녕하세요.",
    "Hello %s," : "안녕하세요 %s님,",
    "Admin notifications" : "관리자 알림",
    "Notifications" : "알림",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "이 앱은 Nextcloud 알림 API의 백엔드 및 프론트엔드입니다.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "이 앱은 Nextcloud 알림 API의 백엔드 및 프론트엔드입니다.\n\t\tAPI를 사용하여 다른 앱에서 웹 UI에 알림을 표시하고 클라이언트에 메시지를 전달할 수 있습니다. 다음 기능을 사용할 수 있습니다:\n\n📬 연합 파일 공유: 새 원격 공유 수신\n\n📑 댓글: 다른 사용자가 여러분을 파일에서 언급함\n\n🚢 업데이트 알림: Nextcloud나 앱 업데이트 알림\n\n📣 공지 센터: 관리자가 공지를 올림",
    "Failed to perform action" : "동작을 수행할 수 없음",
    "Dismiss" : "해제",
    "seconds ago" : "초 전",
    "Failed to dismiss notification" : "알림을 해제할 수 없음",
    "in {path}" : "{path}에 있음",
    "Dismiss all notifications" : "모든 알림 해제",
    "No notifications" : "알림 없음",
    "Failed to dismiss all notifications" : "모든 알림을 해제할 수 없음",
    "Send email reminders about unhandled notifications after:" : "다음 기간동안 확인하지 않은 알림을 이메일로 보내기:",
    "Play sound when a new notification arrives" : "새로운 알림이 도착할 때 소리 재생하기",
    "Play sound when a call started (requires Nextcloud Talk)" : "새 통화가 시작될 때 소리 재생하기 (Nextcloud 토크 필요}",
    "Never" : "하지 않음",
    "1 hour" : "1시간",
    "3 hours" : "3시간",
    "1 day" : "1일",
    "1 week" : "1주",
    "Your settings have been updated." : "설정이 업데이트되었습니다.",
    "You need to set up your email address before you can receive notification emails." : "알림 이메일을 받으려면 이메일 주소를 설정해야 합니다."
},
"nplurals=1; plural=0;");
